summaryrefslogtreecommitdiffstats
path: root/ssl/ssl_init.c
diff options
context:
space:
mode:
authorMatt Caswell <matt@openssl.org>2016-04-04 13:43:58 +0100
committerMatt Caswell <matt@openssl.org>2016-04-13 08:52:33 +0100
commit6827cb3610fee4ec8cc120cc6b5bf88b04884ae7 (patch)
tree1c2bec63a701723843db0e541fe037432336469d /ssl/ssl_init.c
parent02a247e0fa23f2caa9c10df3adf3476eb9813c95 (diff)
Deprecate ERR_free_strings() and make it a no-op
ERR_free_strings() should not be called expicitly - we should leave auto-deinit to clean this up instead. Reviewed-by: Tim Hudson <tjh@openssl.org> Reviewed-by: Richard Levitte <levitte@openssl.org>
Diffstat (limited to 'ssl/ssl_init.c')
-rw-r--r--ssl/ssl_init.c11
1 files changed, 6 insertions, 5 deletions
diff --git a/ssl/ssl_init.c b/ssl/ssl_init.c
index 413fa4105b..2462fa5eab 100644
--- a/ssl/ssl_init.c
+++ b/ssl/ssl_init.c
@@ -57,7 +57,8 @@
#include "e_os.h"
-#include <internal/threads.h>
+#include "internal/threads.h"
+#include "internal/err.h"
#include <openssl/crypto.h>
#include <openssl/evp.h>
#include <assert.h>
@@ -206,15 +207,15 @@ static void ssl_library_stop(void)
if (ssl_strings_inited) {
#ifdef OPENSSL_INIT_DEBUG
fprintf(stderr, "OPENSSL_INIT: ssl_library_stop: "
- "ERR_free_strings()\n");
+ "err_free_strings_intern()\n");
#endif
/*
* If both crypto and ssl error strings are inited we will end up
* calling ERR_free_strings() twice - but that's ok. The second time
* will be a no-op. It's easier to do that than to try and track
* between the two libraries whether they have both been inited.
*/
- ERR_free_strings();
+ err_free_strings_intern();
}
}
@@ -206,15 +207,15 @@ static void ssl_library_stop(void)
/*
* If both crypto and ssl error strings are inited we will end up
- * calling ERR_free_strings() twice - but that's ok. The second time
- * will be a no-op. It's easier to do that than to try and track
+ * calling err_free_strings_intern() twice - but that's ok. The second
+ * time will be a no-op. It's easier to do that than to try and track
* between the two libraries whether they have both been inited.
*/